Module types

Module types 

Type definitions for EPUB book components.

This module contains all the data structures used to represent the extracted content from an EPUB file:

  • Metadata: Dublin Core metadata
  • Page: Text content pages
  • Image: Images including cover
  • TocEntry: Table of contents navigation

Structs

Image
An image extracted from an EPUB file.
Metadata
Dublin Core metadata extracted from an EPUB file.
Page
A single page of text content from an EPUB book.
TocEntry
An entry in the EPUB table of contents.